## $Id: browser.py 16997 2022-07-06 11:38:52Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for basic applicants and related components.
"""
import grok
from zope.formlib.textwidgets import BytesDisplayWidget
from waeup.kofa.applicants.pdf import PDFApplicationSlip
from waeup.kofa.applicants.browser import (
    ApplicantRegistrationPage, ApplicantsContainerPage,
    ApplicantDisplayFormPage,
    ApplicantManageFormPage,
    ApplicantEditFormPage)

from kofacustom.lpng.applicants.interfaces import (
    ICustomApplicant,
    ICustomApplicantOnlinePayment,
    )

from kofacustom.lpng.interfaces import MessageFactory as _

        
class CustomApplicantDisplayFormPage(ApplicantDisplayFormPage):
    """A display view for applicant data.
    """

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomApplicant)
        form_fields['perm_address'].custom_widget = BytesDisplayWidget
        form_fields['notice'].custom_widget = BytesDisplayWidget
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        return form_fields

class CustomPDFApplicationSlip(PDFApplicationSlip):

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomApplicant)
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        return form_fields

class CustomApplicantManageFormPage(ApplicantManageFormPage):
    """A full edit view for applicant data.
    """

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomApplicant)
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        form_fields['applicant_id'].for_display = True
        return form_fields

class CustomApplicantEditFormPage(ApplicantEditFormPage):
    """An applicant-centered edit view for applicant data.
    """

    def unremovable(self, ticket):
        return True

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomApplicant)
        form_fields = form_fields.omit('notice')
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        form_fields['applicant_id'].for_display = True
        form_fields['reg_number'].for_display = True
        return form_fields

